==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/icmp/type/grouping/NxmOfIcmpType.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.icmp.type.grouping;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmOfIcmpTypeGrouping;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-of-icmp-type {
 *     leaf value {
 *         type uint8;
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-of-icmp-type-grouping/nxm-of-icmp-type</i>
 *
 * <p>To create instances of this class use {@link NxmOfIcmpTypeBuilder}.
 * @see NxmOfIcmpTypeBuilder
 *
 */
public interface NxmOfIcmpType
    extends
    ChildOf<NxmOfIcmpTypeGrouping>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.icmp.type.grouping.NxmOfIcmpType>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:match",
        "2014-07-14", "nxm-of-icmp-type").intern();

    /**
     * @return <code>java.lang.Short</code> <code>value</code>, or <code>null</code> if not present
     */
    java.lang.Short getValue();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/icmp/type/grouping/NxmOfIcmpType.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.icmp.type.grouping;
import java.lang.Short;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmOfIcmpTypeGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-of-icmp-type {
 *   leaf value {
 *     type uint8;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-of-icmp-type-grouping/nxm-of-icmp-type</i>
 *
 * <p>To create instances of this class use {@link NxmOfIcmpTypeBuilder}.
 * @see NxmOfIcmpTypeBuilder
 *
 */
public interface NxmOfIcmpType
    extends
    ChildOf<NxmOfIcmpTypeGrouping>,
    Augmentable<NxmOfIcmpType>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-of-icmp-type");

    /**
     * @return <code>java.lang.Short</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Short getValue();

}
